==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/61/61e167eea60bb47b8b05f8bd621e2e3f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php */
class __TwigTemplate_d67aacf5d9cdc445ba15c9620fb6d2ea extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Sync\\DAO\\Sync;

use Mautic\\IntegrationsBundle\\Sync\\DAO\\Value\\NormalizedValueDAO;

class InformationChangeRequestDAO
{
    private ?\\DateTimeInterface \$possibleChangeDateTime = null;

    private ?\\DateTimeInterface \$certainChangeDateTime = null;

    /**
     * @param string \$integration
     * @param string \$objectName
     * @param mixed  \$objectId
     * @param string \$field
     */
    public function __construct(
        private \$integration,
        private \$objectName,
        private \$objectId,
        private \$field,
        private NormalizedValueDAO \$newValue
    ) {
    }

    public function getIntegration(): string
    {
        return \$this->integration;
    }

    /**
     * @return mixed
     */
    public function getObjectId()
    {
        return \$this->objectId;
    }

    public function getObject(): string
    {
        return \$this->objectName;
    }

    public function getField(): string
    {
        return \$this->field;
    }

    public function getNewValue(): NormalizedValueDAO
    {
        return \$this->newValue;
    }

    public function getPossibleChangeDateTime(): ?\\DateTimeInterface
    {
        return \$this->possibleChangeDateTime;
    }

    public function setPossibleChangeDateTime(?\\DateTimeInterface \$possibleChangeDateTime = null): self
    {
        \$this->possibleChangeDateTime = \$possibleChangeDateTime;

        return \$this;
    }

    public function getCertainChangeDateTime(): ?\\DateTimeInterface
    {
        return \$this->certainChangeDateTime;
    }

    public function setCertainChangeDateTime(?\\DateTimeInterface \$certainChangeDateTime = null): self
    {
        \$this->certainChangeDateTime = \$certainChangeDateTime;

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php", "/var/www/mautic-ktn/app/bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/61/61e167eea60bb47b8b05f8bd621e2e3f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php */
class __TwigTemplate_d67aacf5d9cdc445ba15c9620fb6d2ea extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Sync\\DAO\\Sync;

use Mautic\\IntegrationsBundle\\Sync\\DAO\\Value\\NormalizedValueDAO;

class InformationChangeRequestDAO
{
    private ?\\DateTimeInterface \$possibleChangeDateTime = null;

    private ?\\DateTimeInterface \$certainChangeDateTime = null;

    /**
     * @param string \$integration
     * @param string \$objectName
     * @param mixed  \$objectId
     * @param string \$field
     */
    public function __construct(
        private \$integration,
        private \$objectName,
        private \$objectId,
        private \$field,
        private NormalizedValueDAO \$newValue
    ) {
    }

    public function getIntegration(): string
    {
        return \$this->integration;
    }

    /**
     * @return mixed
     */
    public function getObjectId()
    {
        return \$this->objectId;
    }

    public function getObject(): string
    {
        return \$this->objectName;
    }

    public function getField(): string
    {
        return \$this->field;
    }

    public function getNewValue(): NormalizedValueDAO
    {
        return \$this->newValue;
    }

    public function getPossibleChangeDateTime(): ?\\DateTimeInterface
    {
        return \$this->possibleChangeDateTime;
    }

    public function setPossibleChangeDateTime(?\\DateTimeInterface \$possibleChangeDateTime = null): self
    {
        \$this->possibleChangeDateTime = \$possibleChangeDateTime;

        return \$this;
    }

    public function getCertainChangeDateTime(): ?\\DateTimeInterface
    {
        return \$this->certainChangeDateTime;
    }

    public function setCertainChangeDateTime(?\\DateTimeInterface \$certainChangeDateTime = null): self
    {
        \$this->certainChangeDateTime = \$certainChangeDateTime;

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Sync/DAO/Sync/InformationChangeRequestDAO.php");
    }
}
